fn main() -> Result<(), Box<dyn std::error::Error>> {
    println!("cargo:rerun-if-changed=src/proto/mlp.proto");
    tonic_build::configure()
        .type_attribute("MumbleIdentity", "#[derive(serde::Deserialize)]")
        .type_attribute("WindowDimensions", "#[derive(Copy)]")
        .type_attribute("MumbleContext", "#[derive(Copy)]")
        .compile(&["src/proto/mlp.proto"], &["src/proto"])?;
    // tonic_build::compile_protos("proto/mlp.proto")?;
    Ok(())
}
